==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/STANDARDCREWRATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for STANDARDCREWRATEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STANDARDCREWRATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDCREWID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STANDARDCREWRATEID_Type", propOrder = {
    "standardcrewid",
    "organizationid",
    "departmentid",
    "startdate"
})
public class STANDARDCREWRATEID_Type {

    @XmlElement(name = "STANDARDCREWID", required = true)
    protected CREWID_Type standardcrewid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the standardcrewid property.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getSTANDARDCREWID() {
        return standardcrewid;
    }

    /**
     * Sets the value of the standardcrewid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setSTANDARDCREWID(CREWID_Type value) {
        this.standardcrewid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/STANDARDCREWRATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for STANDARDCREWRATEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="STANDARDCREWRATEID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STANDARDCREWID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STANDARDCREWRATEID_Type", propOrder = {
    "standardcrewid",
    "organizationid",
    "departmentid",
    "startdate"
})
public class STANDARDCREWRATEID_Type {

    @XmlElement(name = "STANDARDCREWID", required = true)
    protected CREWID_Type standardcrewid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DEPARTMENTID", required = true)
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the standardcrewid property.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getSTANDARDCREWID() {
        return standardcrewid;
    }

    /**
     * Sets the value of the standardcrewid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setSTANDARDCREWID(CREWID_Type value) {
        this.standardcrewid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}
